==> nova_alarm_plugin-0.0.3.tar.gz: ios/Classes/SwiftNovaAlarmPlugin.swift <==
import Flutter
import UIKit

public class SwiftNovaAlarmPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "nova_alarm_plugin", binaryMessenger: registrar.messenger())
    let instance = SwiftNovaAlarmPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    if call.method == "getPlatformVersion" {
            result("iOS " + UIDevice.current.systemVersion)
        } else if call.method == "requestClockPermission" {
            self.requestAuthorization(call, result: result)
        } else if call.method == "isClockAvailable" {
            self.getAuthorizationStatus(call, result: result)
        } else if call.method == "setClock" {
            self.setLocalNotification(call, result: result)
        } else if call.method == "cancelAllClock" {
            self.closePendingNotification(call, result: result)
        } else if call.method == "closeNotification" {
            self.closeDeliveredLocalNotification(call, result: result)
        }
  }



    public func requestAuthorization(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        UNUserNotificationCenter.current().requestAuthorization(options: [.alert, .badge, .sound]) { (succeed, _) in
            result(succeed)
        }
    }
    
    public func getAuthorizationStatus(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        UNUserNotificationCenter.current().getNotificationSettings { (settings) in
            result(settings.authorizationStatus == .authorized)
        }
    }
    
    
    
    public func setLocalNotification(_ call: FlutterMethodCall, result: @escaping FlutterResult) {

        /**
         var kParams = {
         "time": time,
         "activityId": activityName,
         "ringName": ringName,
         "title": title,
         "content": content,
         };
         */
        
        UNUserNotificationCenter.current().getNotificationSettings { (settings) in
            
            // 没有权限
            guard settings.authorizationStatus == .authorized else {
                result(false)
                return
            }
            
            guard let arguments = call.arguments as? [String: Any],
                let activityId = arguments["activityId"] as? String,
                let timeString = arguments["time"] as? String,
                var time = Double(timeString),
                let title = arguments["title"] as? String,
                let body = arguments["content"] as? String else {
                result(false)
                return
            }
            
            let content = UNMutableNotificationContent()
            content.title = title
            content.body = body
            
            // 设置铃声
            
            if let sound = arguments["ringName"] as? String {
                let notificationSound = UNNotificationSound(named: UNNotificationSoundName(sound))
                content.sound = notificationSound
            } else {
                // 不设置没声音 不知道为什么
                content.sound = UNNotificationSound(named: UNNotificationSoundName(""))
            }
            
            // 设置时间
            // 时间戳是毫秒长度是13位
            // 秒的时间戳是10位，例如php时间戳
            if timeString.count == 13 {
                time = time / 1000
            }
            
            let currentTimeInterval = Date().timeIntervalSince1970
            if time <= currentTimeInterval {
                // 传进来的时间是过去的时间
                result(false)
                return
            }
            
            // 距离现在的时间差
            let timeInterval = time - currentTimeInterval
            /**
             2019-12-13 11:16:46.309296+0800 Runner[17888:322363] *** Terminating app due to uncaught exception 'NSInternalInconsistencyException', reason: 'time interval must be at least 60 if repeating'
             */
            var repeats = true
            if let repeats_arguments = arguments["repeats"] as? Bool {
                repeats = repeats_arguments
            } else {
                if timeInterval < 60 {
                    repeats = false
                }
            }
            
            let trigger = UNTimeIntervalNotificationTrigger(timeInterval: 10, repeats: false)
            
            let request = UNNotificationRequest(identifier: activityId, content: content, trigger: trigger)

            UNUserNotificationCenter.current().add(request, withCompletionHandler: { (error) in
                result(error == nil)
            })
        }
        
    }
    
    public func closePendingNotification(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String: Any],
            let activityId = arguments["activityName"] as? String {
            UNUserNotificationCenter.current().removePendingNotificationRequests(withIdentifiers: [activityId])
        } else {
            UNUserNotificationCenter.current().removeAllPendingNotificationRequests()
        }
        result(true)
    }
    
    public func closeDeliveredLocalNotification(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        UNUserNotificationCenter.current().removeAllDeliveredNotifications()
        result(true)
    }
}

==> nova_alarm_plugin-0.0.8.tar.gz: ios/Classes/SwiftNovaAlarmPlugin.swift <==
import Flutter
import UIKit

public class SwiftNovaAlarmPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "nova_alarm_plugin", binaryMessenger: registrar.messenger())
    let instance = SwiftNovaAlarmPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    if call.method == "getPlatformVersion" {
            result("iOS " + UIDevice.current.systemVersion)
        } else if call.method == "requestClockPermission" {
            self.requestAuthorization(call, result: result)
        } else if call.method == "isClockAvailable" {
            self.getAuthorizationStatus(call, result: result)
        } else if call.method == "setClock" {
            self.setLocalNotification(call, result: result)
        } else if call.method == "cancelAllClock" {
            self.closePendingNotification(call, result: result)
        } else if call.method == "closeNotification" {
            self.closeDeliveredLocalNotification(call, result: result)
        }
  }



    public func requestAuthorization(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        UNUserNotificationCenter.current().requestAuthorization(options: [.alert, .badge, .sound]) { (succeed, _) in
            result(succeed)
        }
    }
    
    public func getAuthorizationStatus(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        UNUserNotificationCenter.current().getNotificationSettings { (settings) in
            result(settings.authorizationStatus == .authorized)
        }
    }
    
    
    
    public func setLocalNotification(_ call: FlutterMethodCall, result: @escaping FlutterResult) {

        /**
         var kParams = {
         "time": time,
         "activityId": activityName,
         "ringName": ringName,
         "title": title,
         "content": content,
         };
         */
        
        UNUserNotificationCenter.current().getNotificationSettings { (settings) in
            
            // 没有权限
            guard settings.authorizationStatus == .authorized else {
                result(false)
                return
            }
            
            guard let arguments = call.arguments as? [String: Any],
                let activityId = arguments["activityId"] as? String,
                let timeString = arguments["time"] as? String,
                var time = Double(timeString),
                let title = arguments["title"] as? String,
                let body = arguments["content"] as? String else {
                result(false)
                return
            }
            
            let content = UNMutableNotificationContent()
            content.title = title
            content.body = body
            
            // 设置铃声
            
            if let sound = arguments["ringName"] as? String {
                let notificationSound = UNNotificationSound(named: UNNotificationSoundName(sound))
                content.sound = notificationSound
            } else {
                // 不设置没声音 不知道为什么
                content.sound = UNNotificationSound(named: UNNotificationSoundName(""))
            }
            
            // 设置时间
            // 时间戳是毫秒长度是13位
            // 秒的时间戳是10位，例如php时间戳
            if timeString.count == 13 {
                time = time / 1000
            }
            
            let currentTimeInterval = Date().timeIntervalSince1970
            if time <= currentTimeInterval {
                // 传进来的时间是过去的时间
                result(false)
                return
            }
            
            // 距离现在的时间差
            let timeInterval = time - currentTimeInterval
            /**
             2019-12-13 11:16:46.309296+0800 Runner[17888:322363] *** Terminating app due to uncaught exception 'NSInternalInconsistencyException', reason: 'time interval must be at least 60 if repeating'
             */
            var repeats = true
            if let repeats_arguments = arguments["repeats"] as? Bool {
                repeats = repeats_arguments
            } else {
                if timeInterval < 60 {
                    repeats = false
                }
            }
            
            let trigger = UNTimeIntervalNotificationTrigger(timeInterval: timeInterval, repeats: repeats)
            
            let request = UNNotificationRequest(identifier: activityId, content: content, trigger: trigger)

            UNUserNotificationCenter.current().add(request, withCompletionHandler: { (error) in
                result(error == nil)
            })
        }
        
    }
    
    public func closePendingNotification(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String: Any],
            let activityId = arguments["activityName"] as? String {
            UNUserNotificationCenter.current().removePendingNotificationRequests(withIdentifiers: [activityId])
        } else {
            UNUserNotificationCenter.current().removeAllPendingNotificationRequests()
        }
        result(true)
    }
    
    public func closeDeliveredLocalNotification(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        UNUserNotificationCenter.current().removeAllDeliveredNotifications()
        result(true)
    }
}
